Package: SAMprior
Type: Package
Title: Self-Adapting Mixture (SAM) Priors
Version: 3.0.0
Authors@R: c(person(given = "Peng", family = "Yang", email = "pyang7@mdanderson.org", 
                    role = c("aut", "cre"),
                    comment = c(ORCID = "0000-0002-0630-9506")), 
             person(given = "Ying", family = "Yuan", email = "yyuan@mdanderson.org", 
                    role = "aut",
                    comment = c(ORCID = "0000-0003-3163-480X")))
Maintainer: Peng Yang <pyang7@mdanderson.org>
Description: Implementation of the SAM prior and generation of its
     operating characteristics for dynamically borrowing information
     from historical data. For details, please refer to Yang et al. (2023)
     <doi:10.1111/biom.13927>. 
Depends: R (>= 3.5.0), RBesT, MatchIt
Imports: Metrics, assertthat, checkmate, ggplot2
Suggests: rmarkdown, knitr, testthat (>= 2.0.0), foreach, purrr,
        rstanarm (>= 2.17.2), scales, tools, broom, tidyr, parallel
VignetteBuilder: knitr
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-27 20:54:08 UTC; pyang7
Author: Peng Yang [aut, cre] (ORCID: <https://orcid.org/0000-0002-0630-9506>),
  Ying Yuan [aut] (ORCID: <https://orcid.org/0000-0003-3163-480X>)
Repository: CRAN
Date/Publication: 2026-04-27 22:10:02 UTC
Built: R 4.6.0; ; 2026-05-01 22:28:47 UTC; unix
