# Generated by roxygen2: do not edit by hand

S3method(SAM_prior,betaMix)
S3method(SAM_prior,default)
S3method(SAM_prior,gammaMix)
S3method(SAM_prior,normMix)
S3method(SAM_weight,betaMix)
S3method(SAM_weight,default)
S3method(SAM_weight,gammaMix)
S3method(SAM_weight,normMix)
S3method(calibrate_cutoff_2arm,betaMix)
S3method(calibrate_cutoff_2arm,default)
S3method(calibrate_cutoff_2arm,normMix)
S3method(get_OC,betaMix)
S3method(get_OC,default)
S3method(get_OC,normMix)
S3method(support,betaMix)
S3method(support,default)
S3method(support,gammaMix)
S3method(support,normMix)
export(PS_prior)
export(PS_prior.beta)
export(PS_prior.default)
export(PS_prior.norm)
export(SAM_prior)
export(SAM_weight)
export(calibrate_cutoff_2arm)
export(calibrate_cutoff_bin_2arm)
export(calibrate_cutoff_cont_2arm)
export(eval_oc_bin_2arm)
export(eval_oc_cont_2arm)
export(eval_scenario_bin_2arm)
export(eval_scenario_cont_2arm)
export(get_OC)
export(post_summary_bin_2arm)
export(post_summary_cont_2arm)
import(MatchIt)
import(Metrics)
import(RBesT)
import(assertthat)
import(checkmate)
import(ggplot2)
import(stats)
